@@ -17,8 +17,14 @@
 #' leukemia.surv <- survival::survfit(survival::Surv(time, status) ~ x, data = survival::aml) 
 #' survival:::plot.survfit(leukemia.surv, conf.int = TRUE, lty = 2:3, col = 1:2)
 #' 
+#' qkmplot_bulid_data_frame(leukemia.surv) 
 #' qkmplot(leukemia.surv, conf_int = TRUE) 
 #' 
+#' intonly_fit <- survival::survfit(survival::Surv(time, status) ~ 1, data = survival::aml) 
+#' survival:::plot.survfit(intonly_fit, conf.int = TRUE)
+#' 
+#' qkmplot_bulid_data_frame(intonly_fit) 
+#' qkmplot(intonly_fit, conf_int = TRUE) 
 #' @export   
 #' @rdname qkmplot
 qkmplot <- function(x, conf_int = FALSE, ...) { 
@@ -27,32 +33,36 @@ qkmplot <- function(x, conf_int = FALSE, ...) {
 
 #' @export
 qkmplot.default <- function(x, conf_int = FALSE, ...) { 
-  qkmplot_ggplot(x, ...)
+  qkmplot_ggplot(x, conf_int = conf_int, ...)
 }
 
 #' @export
 qkmplot.survfit <- function(x, conf_int = FALSE, ...) { 
-  qkmplot_ggplot(qkmplot_bulid_data_frame(x), ...)
+  qkmplot_ggplot(qkmplot_bulid_data_frame(x), conf_int = conf_int, ...)
 }
 
 #' @export
 qkmplot.qwraps2_generated <- function(x, conf_int = FALSE, ...) { 
-  qkmplot_ggplot(x, ...)
+  qkmplot_ggplot(x, conf_int = conf_int, ...)
 }
 
-qkmplot_ggplot <- function(.data, conf_int = FALSE, ...) { 
-  layers <- list(ggplot2::aes_string(x = "time", y = "surv", colour = "strata", fill = "strata"),
+qkmplot_ggplot <- function(dat, conf_int = FALSE, ...) { 
+  layers <- list(ggplot2::aes_string(x = "time", y = "surv"),
+                 if (!is.null(dat$strata)) {ggplot2::aes_string(colour = "strata", fill = "strata") } else {NULL},
                  ggplot2::geom_step(),
                  ggplot2::ylim(c(0, 1)),
                  ggplot2::ylab("Survivial"),
-                 ggplot2::geom_point(data = dplyr::filter_(.data, "n.censor" > 0), shape = 3, alpha = 0.9)
+                 ggplot2::geom_point(data = dplyr::filter(dat, .data$n.censor > 0), shape = 3, alpha = 0.9)
                  )
+
   if (conf_int) {
-    layers[[length(layers) + 1L]] <- 
-      ggplot2::geom_ribbon(ggplot2::aes_string(ymin = "lower", ymax = "upper"), alpha = 0.2) 
+    layers <- append(layers,
+                     ggplot2::geom_ribbon(ggplot2::aes_string(ymin = "lower", ymax = "upper"), alpha = 0.2,
+                                          stat = "stepribbon") 
+      )
   }
 
-  ggplot2::ggplot(.data) + layers
+  ggplot2::ggplot(dat) + layers
 }
 
 #' @export   
@@ -63,11 +73,16 @@ qkmplot_bulid_data_frame <- function(x) {
                           n.event = x[['n.event']],
                           n.censor = x[['n.censor']],
                           surv = x[['surv']],
-                          strata = rep(attr(x[['strata']], "names"), times = x[['strata']]), 
+                          # strata = rep(attr(x[['strata']], "names"), times = x[['strata']]), 
                           upper = x[['upper']],
                           lower = x[['lower']], 
                           stringsAsFactors = FALSE) 
-  first_data <- plot_data[!duplicated(plot_data$strata), ]
+  if (!is.null(x$strata)) {
+    plot_data$strata <- rep(attr(x[['strata']], "names"), times = x[['strata']])
+    first_data <- plot_data[!duplicated(plot_data$strata), ]
+  } else {
+    first_data <- plot_data[1, ]
+  }
   first_data$time <- 0
   first_data$surv <- 1
   first_data$n.risk <- NA
@@ -77,7 +92,7 @@ qkmplot_bulid_data_frame <- function(x) {
   first_data$upper <- 1
 
   dat <- rbind(plot_data, first_data)
-  class(dat) <- c(class(dat), "qwraps2_generated")
-  dat
+  class(dat) <- c("qwraps2_generated", class(dat))
+  dplyr::tbl_df(dat)
 } 
 
