@@ -3,7 +3,7 @@ knitr::opts_chunk$set(collapse = TRUE)
 
 ## ------------------------------------------------------------------------
 set.seed(42)
-library(dplyr)
+library(magrittr)
 library(qwraps2)
 
 # define the markup language we are working in.
@@ -86,109 +86,114 @@ args(summary_table)
 ## ------------------------------------------------------------------------
 our_summary1 <-
   list("Miles Per Gallon" =
-       list("min" = ~ min(mpg),
-            "max" = ~ max(mpg),
-            "mean (sd)" = ~ qwraps2::mean_sd(mpg)),
+       list("min" = ~ min(.data$mpg),
+            "max" = ~ max(.data$mpg),
+            "mean (sd)" = ~ qwraps2::mean_sd(.data$mpg)),
        "Displacement" =
-       list("min" = ~ min(disp),
-            "max" = ~ max(disp),
-            "mean (sd)" = ~ qwraps2::mean_sd(disp)),
+       list("min" = ~ min(.data$disp),
+            "median" = ~ median(.data$disp),
+            "max" = ~ max(.data$disp),
+            "mean (sd)" = ~ qwraps2::mean_sd(.data$disp)),
        "Weight (1000 lbs)" =
-       list("min" = ~ min(wt),
-            "max" = ~ max(wt),
-            "mean (sd)" = ~ qwraps2::mean_sd(wt)),
+       list("min" = ~ min(.data$wt),
+            "max" = ~ max(.data$wt),
+            "mean (sd)" = ~ qwraps2::mean_sd(.data$wt)),
        "Forward Gears" =
-       list("Three" = ~ qwraps2::n_perc0(gear == 3),
-            "Four"  = ~ qwraps2::n_perc0(gear == 4),
-            "Five"  = ~ qwraps2::n_perc0(gear == 5))
+       list("Three" = ~ qwraps2::n_perc0(.data$gear == 3),
+            "Four"  = ~ qwraps2::n_perc0(.data$gear == 4),
+            "Five"  = ~ qwraps2::n_perc0(.data$gear == 5))
        )
 
 ## ----results = "asis"----------------------------------------------------
 ### Overall
-summary_table(mtcars2, our_summary1)
-summary_table(mtcars2, our_summary1)
-
-## ----results = "asis"----------------------------------------------------
-### By number of Cylinders
-summary_table(dplyr::group_by(mtcars2, cyl_factor), our_summary1)
-
-## ----results = "asis"----------------------------------------------------
-print(summary_table(dplyr::group_by(mtcars2, cyl_factor), our_summary1),
-      rtitle = "Summary Statistics",
-      cnames = c("Col 1", "Col 2", "Col 3"))
-
-## ------------------------------------------------------------------------
-args(tab_summary)
-
-## ------------------------------------------------------------------------
-tab_summary(mtcars2$mpg)
-
-tab_summary(mtcars2$gear) # gear is a numeric vector!
-tab_summary(factor(mtcars2$gear))
-
-## ------------------------------------------------------------------------
-our_summary2 <-
-  with(mtcars2,
-       list("Miles Per Gallon" = tab_summary(mpg)[c(1, 4, 3)],
-            "Displacement (default summary)" = tab_summary(disp),
-            "Displacement" = c(tab_summary(disp)[c(1, 4, 3)],
-                               "mean (95% CI)" = ~ frmtci(qwraps2::mean_ci(disp))),
-            "Weight (1000 lbs)" = tab_summary(wt)[c(1, 4, 3)],
-            "Forward Gears" = tab_summary(as.character(gear))
-            ))
-
-## ----results = "asis"----------------------------------------------------
-whole <- summary_table(mtcars2, our_summary2)
+whole <- summary_table(mtcars2, our_summary1)
 whole
 
 ## ----results = "asis"----------------------------------------------------
-grouped <- summary_table(dplyr::group_by(mtcars2, am, vs), our_summary2)
-grouped
+### By number of Cylinders
+by_cyl <- summary_table(dplyr::group_by(mtcars2, cyl_factor), our_summary1)
+by_cyl
 
 ## ----results = "asis"----------------------------------------------------
-both <- cbind(whole, grouped)
+both <- cbind(whole, by_cyl)
 both
 
+## ----results = "asis"----------------------------------------------------
+print(both,
+      rtitle = "Summary Statistics",
+      cnames = c("Col 0", "Col 1", "Col 2", "Col 3"))
+
+## ------------------------------------------------------------------------
+mtcars2 %>%
+  dplyr::select(.data$mpg, .data$cyl_factor, .data$wt) %>%
+  qsummary(.)
+
+## ----label="summary_table_mtcars2_default", results = "asis"-------------
+mtcars2 %>%
+  dplyr::select(.data$mpg, .data$cyl_factor, .data$wt) %>%
+  summary_table(.)
+
+## ------------------------------------------------------------------------
+new_summary <-
+  mtcars2 %>%
+  dplyr::select(.data$mpg, .data$cyl_factor, .data$wt) %>%
+  qsummary(.,
+           numeric_summaries = list("Minimum" = "~ min(%s)",
+                                    "Maximum" = "~ max(%s)"),
+           n_perc_args = list(digits = 1, show_symbol = TRUE, show_denom = "always"))
+
+## ----results = "asis"----------------------------------------------------
+summary_table(mtcars2, new_summary)
+
+## ----results = "asis"----------------------------------------------------
+mtcars2 %>%
+  dplyr::group_by(.data$am) %>%
+  summary_table(., new_summary)
+
 ## ------------------------------------------------------------------------
 both %>% str
 
-# another good way to veiw the character matrix
-# print.default(both)
-
 ## ------------------------------------------------------------------------
-pvals <-
-  list(lm(mpg ~ am:vs,  data = mtcars2),
-       lm(disp ~ am:vs, data = mtcars2),
-       lm(disp ~ am:vs, data = mtcars2),  # yeah, silly example this is needed twice
-       lm(wt ~ am:vs,   data = mtcars2)) %>%
+# difference in means
+mpvals <-
+  list(lm(mpg ~ cyl_factor,  data = mtcars2),
+       lm(disp ~ cyl_factor, data = mtcars2),
+       lm(wt ~ cyl_factor,   data = mtcars2)) %>%
   lapply(aov) %>%
   lapply(summary) %>%
   lapply(function(x) x[[1]][["Pr(>F)"]][1]) %>%
   lapply(frmtp) %>%
   do.call(c, .)
-pvals
+
+# Fisher test
+fpval <- frmtp(fisher.test(table(mtcars2$gear, mtcars2$cyl_factor))$p.value)
 
 ## ------------------------------------------------------------------------
 both <- cbind(both, "P-value" = "")
-both[grepl("mean \\(sd\\)", rownames(both)), "P-value"] <- pvals
+both[grepl("mean \\(sd\\)", rownames(both)), "P-value"] <- mpvals
+a <- capture.output(print(both))
+a[grepl("Forward Gears", a)] %<>% sub("&nbsp;&nbsp;\\ \\|$", paste(fpval, "|"), .)
 
 ## ----results = "asis"----------------------------------------------------
-both
-
-## ------------------------------------------------------------------------
-# tab_summary(mpg) ## this errors
-tab_summary(mtcars$mpg)
-with(mtcars, tab_summary(mpg))
-
-## ------------------------------------------------------------------------
-# The same tables:
-summary_table(mtcars, list("MPG 1" = with(mtcars, tab_summary(mpg))))
-summary_table(mtcars, list("MPG 2" = tab_summary(mtcars$mpg)))
+cat(a, sep = "\n")
 
 ## ----results = "asis"----------------------------------------------------
-# Different tables
-summary_table(dplyr::filter(mtcars, am == 0), list("MPG 3" = with(mtcars, tab_summary(mpg))))
-summary_table(dplyr::filter(mtcars, am == 0), list("MPG 4" = tab_summary(mtcars$mpg)))
+gear_summary <-
+  list("Forward Gears" =
+       list("Three" = ~ qwraps2::n_perc0(.data$gear == 3),
+            "Four"  = ~ qwraps2::n_perc0(.data$gear == 4),
+            "Five"  = ~ qwraps2::n_perc0(.data$gear == 5)),
+       "Transmission" =
+       list("Automatic" = ~ qwraps2::n_perc0(.data$am == 0),
+            "Manual"  = ~ qwraps2::n_perc0(.data$am == 1))
+       ) %>%
+setNames(.,
+         c(
+         paste("Forward Gears: ", frmtp(fisher.test(xtabs( ~ gear + cyl_factor, data = mtcars2))$p.value)),
+         paste("Transmission: ",  frmtp(fisher.test(xtabs( ~ am + cyl_factor, data = mtcars2))$p.value)))
+         )
+
+summary_table(dplyr::group_by(mtcars2, cyl_factor), gear_summary)
 
 ## ------------------------------------------------------------------------
 print(sessionInfo(), local = FALSE)
